<?php
// $Id: taxonomy_builder.api.php,v 1.4 2010/03/10 15:59:17 cpliakas Exp $

/**
 * @file
 * Hook definitions for the "Taxonomy Builder API" module.
 */

/**
 * Allows modules to alter the $form_values array prior to it being passed to
 * the taxonomy_save_term() function.  Use hook_taxonomy() in favor of this hook
 * unless you only want the code to be executed when terms are added via
 * Taxonomy Builder API functions or require access to the $hierarchy and/or
 * $level variables.  Note that this hook is invoked before hook_taxonomy().
 *
 * @param $form_values
 *   An array containing the form values that will be passed to the
 *   taxonomy_save_term() function.
 * @param $hierarchy
 *   An array of term names or $form_values arrays in hierarchical order.
 * @param $level
 *   An integer containing the zero-based hierarchical level, 0 being the top
 *   level in the hierarchy.
 * @return
 *   NULL
 */
function hook_taxonomy_builder_term_alter(&$form_values, $hierarchy, $level) {

  // If you are creating a country -> state -> city hierarchy and are positive
  // that all $hierarchy arrays will have three levels, you can automatically
  // set the term description based on the $level of the term being added.
  switch ($level) {
    case 0:
      $form_values['description'] = 'Country';
      break;
    case 1:
      $form_values['description'] = 'State';
      break;
    case 2:
      $form_values['description'] = 'City';
      break;
  }
}

/**
 * Allows modules to take some action after a term has been saved via the
 * taxonomy_save_term() function.  Use hook_taxonomy() in favor of this hook
 * unless you only want the code to be executed when terms are added via
 * Taxonomy Builder API functions or require access to the $hierarchy and/or
 * $level variables.  Note that this hook is invoked after hook_taxonomy().
 *
 * @param $form_values
 *   An array containing the form values that were passed to and returned by the
 *   taxonomy_save_term() function.
 * @param $hierarchy
 *   An array of term names or $form_values arrays in hierarchical order.
 * @param $level
 *   An integer containing the zero-based hierarchical level, 0 being the top
 *   level in the hierarchy.
 * @return
 *   NULL
 */
function hook_taxonomy_builder_term_save($form_values, $hierarchy, $level) {
}
